TEST_CLIENT_ID = '1_34mi8uiv22iowgsc0wggk0c8888cc80s8gk80gco00g0gko8ko'
TEST_CLIENT_SECRET = '15lkcj9ytmm8440ggsco8ogo4ockwgcg04okokcwokkk8cksk8'
TEST_USERNAME = "guest@taipit.ru"  # may be changed to real username
TEST_PASSWORD = "guest"  # change accordingly TEST_USERNAME
